==> nextcloud-18.0.6.tgz: nextcloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "האחסון אינו זמין באופן זמני",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "All files" : "כל הקבצים",
    "Recent" : "אחרונים",
    "Favorites" : "מועדפים",
    "File could not be found" : "הקובץ לא ניתן לאיתור",
    "Move or copy" : "העברה או העתקה",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "Home" : "בית",
    "Close" : "סגירה",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "This will stop your current uploads." : "פעולה זו תעצור את השליחות הנוכחיות שלך.",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Processing files …" : "הקבצים עוברים עיבוד…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Target folder \"{dir}\" does not exist any more" : "תיקיית היעד „{dir}” לא קיים עוד",
    "Not enough free space" : "אין מספיק מקום פנוי",
    "An unknown error has occurred" : "אירעה שגיאה בלתי ידועה",
    "Uploading …" : "מתבצעת העלאה…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} מתוך {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "העלאת הפריט הזה אינה נתמכת",
    "Target folder does not exist any more" : "תיקיית היעד אינה קיימת עוד",
    "Error when assembling chunks, status code {status}" : "שגיאה באיסוף הנתחים, קוד המצב {status}",
    "Actions" : "פעולות",
    "Rename" : "שינוי שם",
    "Copy" : "העתקה",
    "Choose target folder" : "נא לבחור תיקיית יעד",
    "Open" : "פתיחה",
    "Delete file" : "מחיקת קבצים",
    "Delete folder" : "מחיקת תיקייה",
    "Disconnect storage" : "ניתוק אחסון",
    "Unshare" : "הסר שיתוף",
    "Could not load info for file \"{file}\"" : "לא ניתן לטעון מידע על הקובץ „{file}”",
    "Files" : "קבצים",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "copy" : "עותק",
    "Could not copy \"{file}\", target exists" : "לא ניתן להעתיק את „{file}”, היעד קיים",
    "Could not copy \"{file}\"" : "לא ניתן להעתיק את „{file}”",
    "Copied {origin} inside {destination}" : "{origin} הועתק לתוך {destination}                                                                                                                                                                                                                                    ",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "הועתקו {origin} ו־{nbfiles} קבצים אחרים לתוך {destination}",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "Could not fetch file details \"{file}\"" : "לא ניתן לקבל את פרטי הקובץ „{file}”",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "אין תוצאות חיפוש בתיקיות אחרות עבור {tag}{filter}{endtag}",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות","%n תיקיות","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים","%n קבצים","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "_including %n hidden_::_including %n hidden_" : ["לרבות %n מוסתר","לרבות %n מוסתרים","לרבות %n מוסתרים","לרבות %n מוסתרים"],
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים","מעלה %n קבצים","מעלה %n קבצים"],
    "New" : "חדש",
    "Select file range" : "בחירת טווח קבצים",
    "{used} of {quota} used" : "{used} מתוך {quota} בשימוש",
    "{used} used" : "{used} בשימוש",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"/\" is not allowed inside a file name." : "אסור להשתמש ב־„/” בתוך שם קובץ.",
    "\"{name}\" is not an allowed filetype" : "סוד הקובץ „{name}” אינו מורשה",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "View in folder" : "הצג בתיקייה",
    "Copied!" : "ההעתקה הושלמה!",
    "Copy direct link (only works for users who have access to this file/folder)" : "העתקת קישור ישיר (עובד רק עבור משתמשים שיש להם גישה לקובץ/תיקייה זו)",
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים","%n בייטים","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "You can only favorite a single file or folder at a time" : "ניתן להוסיף קובץ או תיקייה בודדים כמועדף בכל פעם",
    "New folder" : "תיקייה חדשה",
    "Upload file" : "העלאת קובץ",
    "Not favorited" : "לא במועדפים",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "Added to favorites" : "נוסף למועדפים",
    "Removed from favorites" : "הוסר מהמועדפים",
    "You added {file} to your favorites" : "הוספת את {file} למועדפים שלך",
    "You removed {file} from your favorites" : "הסרת את {file} מהמועדפים שלך",
    "File changes" : "שינויים בקובץ",
    "Created by {user}" : "נוצר על ידי {user}",
    "Changed by {user}" : "נערך על ידי {user}",
    "Deleted by {user}" : "נמחק על ידי {user}",
    "Restored by {user}" : "שוחזר על ידי {user}",
    "Renamed by {user}" : "השם השתנה על ידי {user}",
    "Moved by {user}" : "הועבר על ידי {user}",
    "\"remote user\"" : "„משתמש מרוחק”",
    "You created {file}" : "יצרת את {file}",
    "You created an encrypted file in {file}" : "יצרת קובץ מוצפן בתוך {file}",
    "{user} created {file}" : " {file} נוצר על ידי {user}",
    "{user} created an encrypted file in {file}" : "נוצר קובץ מוצפן בתוך {file} על ידי {user}",
    "{file} was created in a public folder" : "{file} נוצר בתוך תיקייה ציבורית",
    "You changed {file}" : "שינית את {file}",
    "You changed an encrypted file in {file}" : "שינית קובץ מוצפן בתוך {file}",
    "{user} changed {file}" : "{file} נערך על ידי {user}",
    "{user} changed an encrypted file in {file}" : "קובץ מוצפן בתוך {file} נערך על ידי {user}",
    "You deleted {file}" : "מחקת את {file}",
    "You deleted an encrypted file in {file}" : "מחקת קובץ מוצפן תחת {file}",
    "{user} deleted {file}" : "{file} נמחק על ידי {user}",
    "{user} deleted an encrypted file in {file}" : "קובץ מוצפן בתוך {file} נמחק על ידי {user}",
    "You restored {file}" : "שחזרת את {file}",
    "{user} restored {file}" : "{file} שוחזר על ידי {user}",
    "You renamed {oldfile} to {newfile}" : "שינית את השם של {oldfile} לשם {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "השם של {oldfile} השתנה אל {newfile} על ידי {user}",
    "You moved {oldfile} to {newfile}" : "העברת את {oldfile} אל {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{oldfile} הועבר אל {newfile} על ידי {user}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "קובץ נוסף או הוסר מה<strong>מועדפים</strong> שלך",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "קובץ או תיקייה <strong>נערכו</strong> או ש<strong>שמם השתנה</strong>",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזרו</strong>",
    "Unlimited" : "ללא הגבלה",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "Accept" : "קבלה",
    "Reject" : "דחייה",
    "Incoming ownership transfer from {user}" : "העברת בעלות נכנסת מאת {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "לקבל את {path}?\n\nלתשומת לך: תהליך ההעברה לאחר האישור עשוי לארוך עד כשעה.",
    "Ownership transfer failed" : "העברת הבעלות נכשלה",
    "Your ownership transfer of {path} to {user} failed." : "העברת הבעלות על {path} לידי {user} ממך נכשלה.",
    "The ownership transfer of {path} from {user} failed." : "העברת הבעלות על {path} לידי {user} נכשלה.",
    "Ownership transfer done" : "העברת הבעלות הושלמה",
    "Your ownership transfer of {path} to {user} has completed." : "העברת הבעלות על {path} לידי {user} ממך הושלמה.",
    "The ownership transfer of {path} from {user} has completed." : "העברת הבעלות על {path} לידי {user} הושלמה.",
    "File Management" : "ניהול קבצים",
    "Transfer ownership of a file or folder" : "העברת בעלות על קובץ או תיקייה",
    "Choose file or folder to transfer" : "נא לבחור קובץ או תיקייה להעברה",
    "Change" : "שינוי",
    "New owner" : "בעלים חדשים",
    "Search users" : "חיפוש משתמשים",
    "Choose a file or folder to transfer" : "נא לבחור קובץ או תיקייה להעברה",
    "Transfer" : "העברה",
    "Transfer {path} to {userid}" : "העברת {path} לידי {userid}",
    "Invalid path selected" : "הנתיב שנבחר שגוי",
    "Ownership transfer request sent" : "נשלחה בקשת העברת בעלות",
    "Cannot transfer ownership of a file or folder you don't own" : "אין לך אפשרות להעביר בעלות על קובץ או תיקייה שאין לך בעלות עליהם",
    "Tags" : "תגיות",
    "Error while loading the file data" : "שגיאה בטעינת נתוני הקובץ",
    "Unable to change the favourite state of the file" : "לא ניתן לשנות את מצב ההעדפה של הקובץ",
    "%s used" : "%s בשימוש",
    "%s%% of %s used" : "%s%% מתוך %s בשימוש",
    "%1$s of %2$s used" : "%1$s מתוך %2$s בשימוש",
    "Settings" : "הגדרות",
    "Show hidden files" : "הצגת קבצים נסתרים",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "יש להשתמש בכתובת הזאת כדי לגשת לקבצים שלך דרך WebDAV",
    "Toggle grid view" : "החלפת תצוגת טבלה",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites yet" : "אין מועדפים עדיין",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Deleted files" : "קבצים שנמחקו",
    "Shares" : "שיתופים",
    "Shared with others" : "משותף עם אחרים",
    "Shared with you" : "משותף אתך",
    "Shared by link" : "משותף על ידי קישור",
    "Deleted shares" : "שיתופים שנמחקו",
    "Pending shares" : "שיתופים ממתינים",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "יש להשתמש בכתובת זו כדי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">לגשת לקבצים שלך באמצעות WebDAV</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "אין לך אפשרות להעביר בעלות על קובץ או תיקייה שאין לך בעלות עליהם"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-18.0.8.tgz: nextcloud/apps/files/l10n/he.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "האחסון אינו זמין באופן זמני",
    "Storage invalid" : "אחסון לא חוקי",
    "Unknown error" : "שגיאה בלתי ידועה",
    "File could not be found" : "הקובץ לא ניתן לאיתור",
    "Move or copy" : "העברה או העתקה",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "Home" : "בית",
    "Close" : "סגירה",
    "Favorites" : "מועדפים",
    "Could not create folder \"{dir}\"" : "לא ניתן ליצור את התיקייה \"{dir}\"",
    "This will stop your current uploads." : "פעולה זו תעצור את השליחות הנוכחיות שלך.",
    "Upload cancelled." : "ההעלאה בוטלה.",
    "Processing files …" : "הקבצים עוברים עיבוד…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "לא ניתן להעלות {filename} כיוון שמדובר בתיקייה או שגודלו 0 בייט",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "לא קיים מספיק מקום פנוי, הקובץ המיועד להעלאה {size1} אבל נשאר {size2} בלבד",
    "Target folder \"{dir}\" does not exist any more" : "תיקיית היעד „{dir}” לא קיים עוד",
    "Not enough free space" : "אין מספיק מקום פנוי",
    "An unknown error has occurred" : "אירעה שגיאה בלתי ידועה",
    "Uploading …" : "מתבצעת העלאה…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} מתוך {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "העלאת הפריט הזה אינה נתמכת",
    "Target folder does not exist any more" : "תיקיית היעד אינה קיימת עוד",
    "Error when assembling chunks, status code {status}" : "שגיאה באיסוף הנתחים, קוד המצב {status}",
    "Actions" : "פעולות",
    "Rename" : "שינוי שם",
    "Copy" : "העתקה",
    "Choose target folder" : "נא לבחור תיקיית יעד",
    "Open" : "פתיחה",
    "Delete file" : "מחיקת קבצים",
    "Delete folder" : "מחיקת תיקייה",
    "Disconnect storage" : "ניתוק אחסון",
    "Could not load info for file \"{file}\"" : "לא ניתן לטעון מידע על הקובץ „{file}”",
    "Files" : "קבצים",
    "Details" : "פרטים",
    "Select" : "בחר",
    "Pending" : "ממתין",
    "Unable to determine date" : "לא ניתן לקבוע תאריך",
    "This operation is forbidden" : "פעולה זו אסורה",
    "This directory is unavailable, please check the logs or contact the administrator" : "תיקייה זו לא קיימת, יש לבדוק את הלוגים או ליצור קשר עם המנהל",
    "Could not move \"{file}\", target exists" : "לא ניתן להעביר \"{file}\", קובץ מטרה קיים",
    "Could not move \"{file}\"" : "לא ניתן להעביר \"{file}\"",
    "copy" : "עותק",
    "Could not copy \"{file}\", target exists" : "לא ניתן להעתיק את „{file}”, היעד קיים",
    "Could not copy \"{file}\"" : "לא ניתן להעתיק את „{file}”",
    "Copied {origin} inside {destination}" : "{origin} הועתק לתוך {destination}                                                                                                                                                                                                                                    ",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "הועתקו {origin} ו־{nbfiles} קבצים אחרים לתוך {destination}",
    "{newName} already exists" : "{newName} כבר קיים",
    "Could not rename \"{fileName}\", it does not exist any more" : "לא ניתן לשנות שם \"{fileName}\", הוא כבר לא קיים יותר",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "השם \"{targetName}\" כבר קיים בתיקייה \"{dir}\". יש לבחור שם אחר.",
    "Could not rename \"{fileName}\"" : "לא ניתן לשנות את השם \"{fileName}\"",
    "Could not create file \"{file}\"" : "לא ניתן ליצור את הקובץ \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "לא ניתן ליצור את הקובץ \"{file}\" כיוון שהוא כבר קיים",
    "Could not create folder \"{dir}\" because it already exists" : "לא ניתן ליצור את התיקייה \"{dir}\" כיוון שהיא כבר קיימת",
    "Could not fetch file details \"{file}\"" : "לא ניתן לקבל את פרטי הקובץ „{file}”",
    "Error deleting file \"{fileName}\"." : "שגיאה בזמן מחיקת קובץ \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "אין תוצאות חיפוש בתיקיות אחרות עבור {tag}{filter}{endtag}",
    "Name" : "שם",
    "Size" : "גודל",
    "Modified" : "זמן שינוי",
    "_%n folder_::_%n folders_" : ["%n תיקייה","%n תיקיות","%n תיקיות","%n תיקיות"],
    "_%n file_::_%n files_" : ["%n קובץ","%n קבצים","%n קבצים","%n קבצים"],
    "{dirs} and {files}" : "{dirs} וכן {files}",
    "_including %n hidden_::_including %n hidden_" : ["לרבות %n מוסתר","לרבות %n מוסתרים","לרבות %n מוסתרים","לרבות %n מוסתרים"],
    "You don’t have permission to upload or create files here" : "אין לך הרשאות להעלות או ליצור קבצים כאן",
    "_Uploading %n file_::_Uploading %n files_" : ["מעלה %n קובץ","מעלה %n קבצים","מעלה %n קבצים","מעלה %n קבצים"],
    "New" : "חדש",
    "Select file range" : "בחירת טווח קבצים",
    "{used} of {quota} used" : "{used} מתוך {quota} בשימוש",
    "{used} used" : "{used} בשימוש",
    "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
    "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
    "\"/\" is not allowed inside a file name." : "אסור להשתמש ב־„/” בתוך שם קובץ.",
    "\"{name}\" is not an allowed filetype" : "סוד הקובץ „{name}” אינו מורשה",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "האחסון של {owner} מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Your storage is full, files can not be updated or synced anymore!" : "האחסון שלך מלא, כבר לא ניתן לעדכן ולסנכרן קבצים!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "האחסון של {owner} כמעט מלא ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "שטח האחסון שלך כמעט מלא ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'","מתאים ל- '{filter}'"],
    "View in folder" : "הצג בתיקייה",
    "Copied!" : "ההעתקה הושלמה!",
    "Copy direct link (only works for users who have access to this file/folder)" : "העתקת קישור ישיר (עובד רק עבור משתמשים שיש להם גישה לקובץ/תיקייה זו)",
    "Path" : "נתיב",
    "_%n byte_::_%n bytes_" : ["%n בייט","%n בייטים","%n בייטים","%n בייטים"],
    "Favorited" : "מועדף",
    "Favorite" : "מועדף",
    "You can only favorite a single file or folder at a time" : "ניתן להוסיף קובץ או תיקייה בודדים כמועדף בכל פעם",
    "New folder" : "תיקייה חדשה",
    "Upload file" : "העלאת קובץ",
    "Recent" : "אחרונים",
    "Not favorited" : "לא במועדפים",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "An error occurred while trying to update the tags" : "שגיאה אירעה בזמן עדכון התגיות",
    "Added to favorites" : "נוסף למועדפים",
    "Removed from favorites" : "הוסר מהמועדפים",
    "You added {file} to your favorites" : "הוספת את {file} למועדפים שלך",
    "You removed {file} from your favorites" : "הסרת את {file} מהמועדפים שלך",
    "File changes" : "שינויים בקובץ",
    "Created by {user}" : "נוצר על ידי {user}",
    "Changed by {user}" : "נערך על ידי {user}",
    "Deleted by {user}" : "נמחק על ידי {user}",
    "Restored by {user}" : "שוחזר על ידי {user}",
    "Renamed by {user}" : "השם השתנה על ידי {user}",
    "Moved by {user}" : "הועבר על ידי {user}",
    "\"remote user\"" : "„משתמש מרוחק”",
    "You created {file}" : "יצרת את {file}",
    "You created an encrypted file in {file}" : "יצרת קובץ מוצפן בתוך {file}",
    "{user} created {file}" : " {file} נוצר על ידי {user}",
    "{user} created an encrypted file in {file}" : "נוצר קובץ מוצפן בתוך {file} על ידי {user}",
    "{file} was created in a public folder" : "{file} נוצר בתוך תיקייה ציבורית",
    "You changed {file}" : "שינית את {file}",
    "You changed an encrypted file in {file}" : "שינית קובץ מוצפן בתוך {file}",
    "{user} changed {file}" : "{file} נערך על ידי {user}",
    "{user} changed an encrypted file in {file}" : "קובץ מוצפן בתוך {file} נערך על ידי {user}",
    "You deleted {file}" : "מחקת את {file}",
    "You deleted an encrypted file in {file}" : "מחקת קובץ מוצפן תחת {file}",
    "{user} deleted {file}" : "{file} נמחק על ידי {user}",
    "{user} deleted an encrypted file in {file}" : "קובץ מוצפן בתוך {file} נמחק על ידי {user}",
    "You restored {file}" : "שחזרת את {file}",
    "{user} restored {file}" : "{file} שוחזר על ידי {user}",
    "You renamed {oldfile} to {newfile}" : "שינית את השם של {oldfile} לשם {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "השם של {oldfile} השתנה אל {newfile} על ידי {user}",
    "You moved {oldfile} to {newfile}" : "העברת את {oldfile} אל {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{oldfile} הועבר אל {newfile} על ידי {user}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "קובץ נוסף או הוסר מה<strong>מועדפים</strong> שלך",
    "A file or folder has been <strong>changed</strong>" : "קובץ או תיקייה <strong>שונו<strong/>",
    "All files" : "כל הקבצים",
    "Unlimited" : "ללא הגבלה",
    "Upload (max. %s)" : "העלאה (מקסימום %s)",
    "Accept" : "קבלה",
    "Reject" : "דחייה",
    "Incoming ownership transfer from {user}" : "העברת בעלות נכנסת מאת {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "לקבל את {path}?\n\nלתשומת לך: תהליך ההעברה לאחר האישור עשוי לארוך עד כשעה.",
    "Ownership transfer failed" : "העברת הבעלות נכשלה",
    "Your ownership transfer of {path} to {user} failed." : "העברת הבעלות על {path} לידי {user} ממך נכשלה.",
    "The ownership transfer of {path} from {user} failed." : "העברת הבעלות על {path} לידי {user} נכשלה.",
    "Ownership transfer done" : "העברת הבעלות הושלמה",
    "Your ownership transfer of {path} to {user} has completed." : "העברת הבעלות על {path} לידי {user} ממך הושלמה.",
    "The ownership transfer of {path} from {user} has completed." : "העברת הבעלות על {path} לידי {user} הושלמה.",
    "in %s" : "ב־%s",
    "File Management" : "ניהול קבצים",
    "Transfer ownership of a file or folder" : "העברת בעלות על קובץ או תיקייה",
    "Choose file or folder to transfer" : "נא לבחור קובץ או תיקייה להעברה",
    "Change" : "שינוי",
    "New owner" : "בעלים חדשים",
    "Search users" : "חיפוש משתמשים",
    "Choose a file or folder to transfer" : "נא לבחור קובץ או תיקייה להעברה",
    "Transfer" : "העברה",
    "Transfer {path} to {userid}" : "העברת {path} לידי {userid}",
    "Invalid path selected" : "הנתיב שנבחר שגוי",
    "Ownership transfer request sent" : "נשלחה בקשת העברת בעלות",
    "Cannot transfer ownership of a file or folder you don't own" : "אין לך אפשרות להעביר בעלות על קובץ או תיקייה שאין לך בעלות עליהם",
    "Tags" : "תגיות",
    "Error while loading the file data" : "שגיאה בטעינת נתוני הקובץ",
    "Unable to change the favourite state of the file" : "לא ניתן לשנות את מצב ההעדפה של הקובץ",
    "%s used" : "%s בשימוש",
    "%s%% of %s used" : "%s%% מתוך %s בשימוש",
    "%1$s of %2$s used" : "%1$s מתוך %2$s בשימוש",
    "Settings" : "הגדרות",
    "Show hidden files" : "הצגת קבצים נסתרים",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "יש להשתמש בכתובת הזאת כדי לגשת לקבצים שלך דרך WebDAV",
    "Toggle grid view" : "החלפת תצוגת טבלה",
    "No files in here" : "אין כאן קבצים",
    "Upload some content or sync with your devices!" : "יש להעלות קצת תוכן או לסנכרן עם ההתקנים שלך!",
    "No entries found in this folder" : "לא נמצאו כניסות לתיקייה זו",
    "Select all" : "לבחור הכול",
    "Upload too large" : "העלאה גדולה מידי",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "הקבצים שניסית להעלות חרגו מהגודל המקסימלי להעלאת קבצים על שרת זה.",
    "No favorites yet" : "אין מועדפים עדיין",
    "Files and folders you mark as favorite will show up here" : "קבצים ותיקיות שסומנו על ידך כמועדפים יוצגו כאן",
    "Deleted files" : "קבצים שנמחקו",
    "Shares" : "שיתופים",
    "Shared with others" : "משותף עם אחרים",
    "Shared with you" : "משותף אתך",
    "Shared by link" : "משותף על ידי קישור",
    "Deleted shares" : "שיתופים שנמחקו",
    "Pending shares" : "שיתופים ממתינים",
    "Text file" : "קובץ טקסט",
    "New text file.txt" : "קובץ טקסט חדש.txt",
    "Unshare" : "הסר שיתוף",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "קובץ או תיקייה <strong>נערכו</strong> או ש<strong>שמם השתנה</strong>",
    "A new file or folder has been <strong>created</strong>" : "קובץ או תיקייה חדשים <strong>נוצרו<strong/>",
    "A file or folder has been <strong>deleted</strong>" : "קובץ או תיקייה <strong>נמחקו</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "הגבלת הודעות על יצירת או שינוי <strong>הקבצים המועדפים</strong> שלך <em>(Stream only)</em>",
    "A file or folder has been <strong>restored</strong>" : "קובץ או תיקייה <strong>שוחזרו</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "יש להשתמש בכתובת זו כדי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">לגשת לקבצים שלך באמצעות WebDAV</a>",
    "Cannot transfter ownership of a file or folder you don't own" : "אין לך אפשרות להעביר בעלות על קובץ או תיקייה שאין לך בעלות עליהם"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
